<?php
/**
 * A command class for resending the confirmation link
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebResendLinkCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set special description
		$this->setObjectDescription("Command for resending confirmation link");

		// Create unique ID number
		$this->generateUniqueId();

		// Clean up a little
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance	An instance of a command resolver class
	 * @return	$commandInstance	An instance a prepared command class
	 */
	public final static function createWebResendLinkCommand (CommandResolver $resolverInstance) {
		// Get new instance
		$commandInstance = new WebResendLinkCommand();

		// Set the application instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the given command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get template instance
		$templateInstance = $responseInstance->getTemplateInstance();

		// Get an application instance
		$appInstance = $this->getResolverInstance()->getApplicationInstance();

		// Assign the application data with the template engine
		$templateInstance->assignApplicationData($appInstance);

		// Assign base URL
		$templateInstance->assignConfigVariable('base_url');

		// Get a mailer class
		$mailerInstance = ObjectFactory::createObjectByConfiguredName('mailer_class', array($templateInstance));

		// Load the mail template
		$mailerInstance->loadTemplate('resend_link');

		// Get a user instance from registry
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Add the recipient
		$mailerInstance->addRecipientByUserInstance($userInstance);

		// Use subject line from template
		$mailerInstance->useSubjectFromTemplate();

		// Send the email out
		$mailerInstance->deliverEmail();

		// Send out notification to admin (depends on settings)
		$mailerInstance->sendAdminNotification();
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Filter for checking if account is unconfirmed
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_unconfirmed_class'));
	}
}

// [EOF]
?>
